==> libremail-2.4.1.tar.bz2: libremail/src/iso8859-utf8.c <==
/*
    Fichier iso8859-utf8.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Remplacement des caractres ASCII tendu par leur quivallent UTF-8
    (pour les caractres correspondant  un code entre A0h et FFh)
*/

#include <stdio.h>


/* programme principal */

main (int narg, char *varg[])
{
    int car;  // caractre du fichier  convertir
    int carp; // caractre prcdent


    // utiliser fichiers passs en paramtre  la place du clavier et de l'cran
    if (narg > 1)
        freopen (varg [1], "r", stdin);

    if (narg > 2)
        freopen (varg [2], "w", stdout);

    // lire un caractre
    car = getchar ();

    // tantque non fin de fichier
    while (car != EOF)
    {
        // si le caractre est le dbut d'une squence UTF-8 sur 2 octets
        if (0xC0 <= car && car <= 0xDF)
        {
            // lire le caractre suivant
            carp = car;
            car = getchar ();

            // si on a bien une squence UTF-8
            if ((car & 0xC0) == 0x80)
            {
                // on la recopie telle quelle
                putchar (carp);
                putchar (car);
            }
            // sinon
            else
            {
                // convertir en UTF-8 l'avant dernier caractre
                putchar (0xC3);
                putchar (0x80 | (carp & 0X3F));

                // annuler la lecture du caractre suiuvant
                ungetc (car, stdin);
            }
        }

        // sinon si autre caractre ASCII tendu
        else if (car & 0x80)
        {
            // le convertir en UTF-8
            putchar (0xC2 | ((car & 0x40) >> 6));
            putchar (0x80 | (car & 0X3F));
        }

        // sinon (caractre ASCII non tendu)
        else
            // simple copie de ce caractre
            putchar (car);

        // lire le caractre suivant
        car = getchar ();
    }

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}

==> libremail-2.5.3.tar.bz2: libremail/src/iso8859-utf8.c <==
/*
    Fichier iso8859-utf8.c
    Auteur Bernard Chardonneau

    Logiciel libre, droits d'utilisation prciss en franais
    dans le fichier : licence-fr.txt

    Traductions des droits d'utilisation dans les fichiers :
    licence-de.txt , licence-en.txt , licence-es.txt ,
    licence-it.txt , licence-nl.txt , licence-pt.txt ,
    licence-eo.txt , licence-eo-utf.txt

    Droits d'utilisation galement sur la page web :
    http://libremail.tuxfamily.org/voir.php?page=droits


    Remplacement des caractres ASCII tendu par leur quivalent UTF-8
    (pour les caractres correspondant  un code entre A0h et FFh)
*/

#include <stdio.h>


/* programme principal */

main (int narg, char *varg[])
{
    int car;  // caractre du fichier  convertir
    int carp; // caractre prcdent


    // utiliser fichiers passs en paramtre  la place du clavier et de l'cran
    if (narg > 1)
        freopen (varg [1], "r", stdin);

    if (narg > 2)
        freopen (varg [2], "w", stdout);

    // lire un caractre
    car = getchar ();

    // tantque non fin de fichier
    while (car != EOF)
    {
        // si le caractre est le dbut d'une squence UTF-8 sur 2 octets
        if (0xC0 <= car && car <= 0xDF)
        {
            // lire le caractre suivant
            carp = car;
            car = getchar ();

            // si on a bien une squence UTF-8
            if ((car & 0xC0) == 0x80)
            {
                // on la recopie telle quelle
                putchar (carp);
                putchar (car);
            }
            // sinon
            else
            {
                // convertir en UTF-8 l'avant dernier caractre
                putchar (0xC3);
                putchar (0x80 | (carp & 0X3F));

                // annuler la lecture du caractre suiuvant
                ungetc (car, stdin);
            }
        }

        // sinon si autre caractre ASCII tendu
        else if (car & 0x80)
        {
            // le convertir en UTF-8
            putchar (0xC2 | ((car & 0x40) >> 6));
            putchar (0x80 | (car & 0X3F));
        }

        // sinon (caractre ASCII non tendu)
        else
            // simple copie de ce caractre
            putchar (car);

        // lire le caractre suivant
        car = getchar ();
    }

    // pour faire plaisir  gcc qui veut une fonction main de type int
    return (0);
}
